@@ -8,7 +8,7 @@ use POSIX qw/ceil floor/;
 use Scalar::Util qw/blessed looks_like_number/;
 require Exporter;
 
-our $VERSION = '0.018';
+our $VERSION = '1.000';
 our @ISA = 'Exporter';
 our @EXPORT_OK = 'calc';
 our $ERROR;
@@ -171,12 +171,12 @@ sub remove_functions {
 }
 
 my $token_re = qr{(
-	( 0x[0-9a-f]+ | 0b[01]+ | 0[0-7]+ ) # Octal/hex/binary numbers
-	| (?: \d*\. )? \d+ (?: e[-+]?\d+ )? # Decimal numbers
-	| [(),]                             # Parentheses and commas
-	| \w+                               # Functions
-	| (?: [-+*/^%!] | << | >> )         # Operators
-	| [^\s\w(),.\-+*/^%!<>]+            # Unknown tokens (but skip whitespace)
+	( 0x[0-9a-f]+ | 0b[01]+ | 0[0-7]+ )          # Octal/hex/binary numbers
+	| (?: [0-9]*\. )? [0-9]+ (?: e[-+]?[0-9]+ )? # Decimal numbers
+	| [(),]                                      # Parentheses and commas
+	| \w+                                        # Functions
+	| (?: [-+*/^%!] | << | >> )                  # Operators
+	| [^\s\w(),.\-+*/^%!<>]+                     # Unknown tokens (but skip whitespace)
 )}ix;
 
 sub parse {
